==> nextcloud-app-tasks-0.13.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/es_CO.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Importante",
    "Today" : "Hoy",
    "Week" : "Semana",
    "All" : "Todos",
    "Current" : "Actual",
    "Completed" : "Completado",
    "Tasks" : "Tareas",
    "New List" : "Nueva Lista",
    "Cancel" : "Cancelar",
    "Save" : "Guardar",
    "An empty name is not allowed." : "No se permite un nombre vacío.",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "can edit" : "puede editar",
    "Edit" : "Editar",
    "Download" : "Descargar",
    "Delete" : "Borrar",
    "Unshare" : "Dejar de compartir",
    "Visibility of Smart Collections" : "Visibilidad de Colecciones Inteligentes",
    "Hidden" : "Oculto",
    "Visible" : "Visible",
    "Automatic" : "Automático",
    "Change sort order" : "Cambiar el criterio para ordenar",
    "Start date" : "Fecha de inicio",
    "Due date" : "Fecha de vencimiento",
    "Last modified" : "Última modificación",
    "Priority" : "Prioridad",
    "Alphabetically" : "Alfabéticamente",
    "Manually" : "Manualmente",
    "Task is completed" : "La tarea ha sido completada",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tarea Completada","%n Tareas Completadas"],
    "Tomorrow" : "Mañana",
    "Set start date" : "Establecer fecha de inicio",
    "Set due date" : "Establecer fecha de vencimiento",
    "All day" : "Todo el día",
    "Task not found!" : "¡Tarea no encontrada!",
    "When shared show full event" : "Al compartir, mostrar el evento completo",
    "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
    "When shared hide this event" : "Al compartir, ocultar este evento "
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-tasks-0.14.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/es_CO.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Importante",
    "Today" : "Hoy",
    "Week" : "Semana",
    "All" : "Todos",
    "Current" : "Actual",
    "Completed" : "Completado",
    "Tasks" : "Tareas",
    "Visibility of Smart Collections" : "Visibilidad de Colecciones Inteligentes",
    "Hidden" : "Oculto",
    "Visible" : "Visible",
    "Automatic" : "Automático",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "Can edit" : "Puede editar",
    "Edit" : "Editar",
    "Export" : "Exportar",
    "Delete" : "Borrar",
    "Unshare" : "Dejar de compartir",
    "Save" : "Guardar",
    "An empty name is not allowed." : "No se permite un nombre vacío.",
    "Name" : "Nombre",
    "Deleted" : "Borrado",
    "Restore" : "Restaurar",
    "Delete permanently" : "Borrar permanentemente",
    "Empty trash bin" : "Vacíar la papelera",
    "Change sort order" : "Cambiar el criterio para ordenar",
    "Start date" : "Fecha de inicio",
    "Due date" : "Fecha de vencimiento",
    "Last modified" : "Última modificación",
    "Priority" : "Prioridad",
    "Alphabetically" : "Alfabéticamente",
    "Manually" : "Manualmente",
    "Task is completed" : "La tarea ha sido completada",
    "Cancel" : "Cancelar",
    "Close" : "Cerrar",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tarea Completada","%n Tareas Completadas","%n Tareas Completadas"],
    "Tomorrow" : "Mañana",
    "New List" : "Nueva Lista",
    "All day" : "Todo el día",
    "Details" : "Detalles",
    "Select tags" : "Selecciona las etiquetas",
    "Notes" : "Notas",
    "Reminders" : "Recordatorios",
    "Repeat" : "Repetir",
    "When shared show full event" : "Al compartir, mostrar el evento completo",
    "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
    "When shared hide this event" : "Al compartir, ocultar este evento ",
    "Task not found!" : "¡Tarea no encontrada!",
    "Set start date" : "Establecer fecha de inicio",
    "Set due date" : "Establecer fecha de vencimiento"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
